
class Animation
{
  Camera cam;
  long start;
  long end;
  long previous;
  float rX, rY, rZ, mX, mY, mZ;

  public Animation(Camera cam, long start, long end, float rX, float rY, float rZ, float mX, float mY, float mZ)
  {
    init(cam, start, end, rX, rY, rZ, mX, mY, mZ); 
  }

  public void init(Camera cam, long start, long end, float rX, float rY, float rZ, float mX, float mY, float mZ)
  {
    this.start = start;
    this.previous = start;
    this.end = end; 

    this.rX = rX;
    this.rY = rY;
    this.rZ = rZ;
    this.mX = mX;
    this.mY = mY;
    this.mZ = mZ;

    this.cam = cam;
  }

  //returns true when the animation is over
  public boolean update(GL gl, GLU glu, long current)
  {
    boolean readyToRemove = false;
    if (current <= start)
    {
      return false; //do nothing, we are not ready to change
    }

    if (current >= end)
    {
      //move to end, then detach myself from the camera
      current = end;
      readyToRemove = true;  
    }

    float lastTimePercentage = (float)(previous - start) / (float)(end - start);
    float thisTimePercentage = (float)(current - start) / (float)(end - start);
    float percDiff = thisTimePercentage - lastTimePercentage;

    cam.rotateCamX(rX * percDiff);
    cam.rotateCamY(rY * percDiff);
    cam.rotateCamZ(rZ * percDiff);
    cam.moveCamX(mX * percDiff);
    cam.moveCamY(mY * percDiff);
    cam.moveCamZ(mZ * percDiff);
    
    previous = current;

    return readyToRemove;   
  }


}

