public int initShaders(String vertexShaderName, String fragmentShaderName )
{
  int vertexID = -1;
  int fragmentID = -1;
  
  //Create GLSL Program
  int programID = gl.glCreateProgram();
  println("Successfully created GLSL program, id=" + programID);
  
  //Create & Load GLSL Vertex and Fragment Shader
  try
  {
    vertexID = loadAndCompileShaderFromFile(gl, GL.GL_VERTEX_SHADER, new File(dataPath(vertexShaderName)));
    fragmentID = loadAndCompileShaderFromFile(gl, GL.GL_FRAGMENT_SHADER, new File(dataPath(fragmentShaderName)));
  }
  catch(IOException ex)
  {
    println("failed to load shader programs...");
    ex.printStackTrace();
  }

  //Attach GLSL Shaders to GLSL Program
  println("attaching GLSL shaders to GLSL program...");
  gl.glAttachShader(programID, vertexID);
  gl.glAttachShader(programID, fragmentID);
  
  //Link GLSL Program to OpenGL Context
  println("linking GLSL program to OpenGL context...");
  gl.glLinkProgram(programID);
  
  return programID;
}

public int initShaders(String vertexShaderName)
{
  int vertexID = -1;
  
  //Create GLSL Program
  int programID = gl.glCreateProgram();
  println("Successfully created GLSL program, id=" + programID);
  
  //Create & Load GLSL Vertex and Fragment Shader
  try
  {
    vertexID = loadAndCompileShaderFromFile(gl, GL.GL_VERTEX_SHADER, new File(dataPath(vertexShaderName)));
  }
  catch(IOException ex)
  {
    println("failed to load shader programs...");
    ex.printStackTrace();
  }

  //Attach GLSL Shaders to GLSL Program
  println("attaching GLSL shaders to GLSL program...");
  gl.glAttachShader(programID, vertexID);
  
  //Link GLSL Program to OpenGL Context
  println("linking GLSL program to OpenGL context...");
  gl.glLinkProgram(programID);
  
  return programID;
}

public int loadAndCompileShaderFromFile(GL gl, int type, File file) throws IOException
{
  BufferedReader reader = null;
  int shaderId = -1;
  try
  {
    reader = new BufferedReader(new FileReader(file));
    ArrayList lineList = new ArrayList(100);

    for (String line = reader.readLine(); line != null; line = reader.readLine())
    {
      lineList.add(line + "\n");
    }

    String[] lines = (String[])lineList.toArray(new String[lineList.size()]);

    int[] lengths = new int[lines.length];
    for (int i = 0; i < lines.length; i++)
    {
      lengths[i] = lines[i].length();
    }


    shaderId = gl.glCreateShader(type);
    gl.glShaderSource(shaderId, lines.length, lines, lengths, 0);
    gl.glCompileShader(shaderId);

    // Check for compile errors
    checkCompileError(gl, shaderId);

  }
  finally
  {
    if (reader != null)
    {
      try
      {
        reader.close();
      }
      catch (Exception ignoreSunsInsanity)
      {
        //do nothing
      }
    }
  }

  return shaderId;
}

private void checkCompileError(GL gl, int shaderId)
{
  IntBuffer status = BufferUtil.newIntBuffer(1);
  gl.glGetShaderiv(shaderId, gl.GL_COMPILE_STATUS, status);

  if (status.get() == gl.GL_FALSE)
  {
    getInfoLog(gl, shaderId);
  }
  else
  {
    System.out.println("Successfully compiled GLSL shader, id=" + shaderId);
  }
}

private void getInfoLog(GL gl, int shaderId)
{
  IntBuffer infoLogLength = BufferUtil.newIntBuffer(1);
  gl.glGetShaderiv(shaderId, gl.GL_INFO_LOG_LENGTH, infoLogLength);

  ByteBuffer infoLog = BufferUtil.newByteBuffer(infoLogLength.get(0));
  gl.glGetShaderInfoLog(shaderId, infoLogLength.get(0), null, infoLog);

  String infoLogString =
    Charset.forName("US-ASCII").decode(infoLog).toString();
  throw new Error("Shader compile error\n" + infoLogString);
}



